## The *check-vpn.ps1* Script

This PowerShell script queries the status of the VPN connections and prints it.

## Parameters
```powershell
/home/mf/Repos/PowerShell/Scripts/check-vpn.ps1 [<CommonParameters>]

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

## Example
```powershell
PS> ./check-vpn
✅ Disconnected VPN 'NASA L2TP'

```

## Notes
Author: Markus Fleschutz | License: CC0

## Related Links
https://github.com/fleschutz/PowerShell

## Source Code
```powershell
<#
.SYNOPSIS
	Checks the VPN status
.DESCRIPTION
	This PowerShell script queries the status of the VPN connections and prints it.
.EXAMPLE
	PS> ./check-vpn
	✅ Disconnected VPN 'NASA L2TP' 
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

try {
	$NoVPN = $true
	if ($IsLinux) {
		# TODO
	} else {
		$Connections = Get-VPNConnection
		foreach($Connection in $Connections) {
			"✅ $($Connection.ConnectionStatus) VPN '$($Connection.Name)'"
			$NoVPN = $false
		}
	}
	if ($NoVPN) { "⚠️ No VPN" }
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*Generated by convert-ps2md.ps1 using the comment-based help of check-vpn.ps1*
