## The *list-outlook-inbox.ps1* Script

This PowerShell script lists the emails in the inbox of Outlook.

## Parameters
```powershell
/home/mf/Repos/PowerShell/Scripts/list-outlook-inbox.ps1 [<CommonParameters>]

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

## Example
```powershell
PS> ./list-outlook-inbox

```

## Notes
Author: Markus Fleschutz | License: CC0

## Related Links
https://github.com/fleschutz/PowerShell

## Source Code
```powershell
<#
.SYNOPSIS
	Lists Outlook's Inbox 
.DESCRIPTION
	This PowerShell script lists the emails in the inbox of Outlook.
.EXAMPLE
	PS> ./list-outlook-inbox
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

try {
	$Outlook = New-Object -com Outlook.application
	$MAPI = $Outlook.GetNameSpace("MAPI")
	$Inbox = $MAPI.GetDefaultFolder(6) # 6 = olFolderInbox
	$Inbox.items | Select Received,Subject | Format-Table -AutoSize
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*Generated by convert-ps2md.ps1 using the comment-based help of list-outlook-inbox.ps1*
