## The *new-script.ps1* Script

This PowerShell script creates a new PowerShell script file (by using template file ../Data/template.ps1).

## Parameters
```powershell
/home/mf/Repos/PowerShell/Scripts/new-script.ps1 [[-filename] <String>] [<CommonParameters>]

-filename <String>
    Specifies the path to the resulting file
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

## Example
```powershell
PS> ./new-script myscript.ps1
✔️ created new PowerShell script: myscript.ps1

```

## Notes
Author: Markus Fleschutz | License: CC0

## Related Links
https://github.com/fleschutz/PowerShell

## Source Code
```powershell
<#
.SYNOPSIS
	Creates a new PowerShell script file
.DESCRIPTION
	This PowerShell script creates a new PowerShell script file (by using template file ../Data/template.ps1).
.PARAMETER filename
	Specifies the path to the resulting file
.EXAMPLE
	PS> ./new-script myscript.ps1
	✔️ created new PowerShell script: myscript.ps1
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$filename = "")

try {
	if ($filename -eq "" ) { $shortcut = read-host "Enter the new filename" }

	copy-item "$PSScriptRoot/../Data/template.ps1" "$filename"

	"✔️ created new PowerShell script: $filename"
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*Generated by convert-ps2md.ps1 using the comment-based help of new-script.ps1*
