## The *speak-file.ps1* Script

This PowerShell script speaks the content of the given text file by text-to-speech (TTS).

## Parameters
```powershell
/home/mf/Repos/PowerShell/Scripts/speak-file.ps1 [[-File] <String>] [<CommonParameters>]

-File <String>
    Specifies the path to the text file
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

## Example
```powershell
PS> ./speak-file C:\MyFile.txt

```

## Notes
Author: Markus Fleschutz | License: CC0

## Related Links
https://github.com/fleschutz/PowerShell

## Source Code
```powershell
<#
.SYNOPSIS
	Speaks file content by text-to-speech
.DESCRIPTION
	This PowerShell script speaks the content of the given text file by text-to-speech (TTS).
.PARAMETER File
	Specifies the path to the text file
.EXAMPLE
	PS> ./speak-file C:\MyFile.txt
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$File = "")

try {
	if ($File -eq "") { $File = read-host "Enter path to text file" }

	$Text = Get-Content $File

	$Voice = new-object -ComObject SAPI.SPVoice
	$Result = $Voice.Speak($Text)
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*Generated by convert-ps2md.ps1 using the comment-based help of speak-file.ps1*
